import 'models.dart';

// This hash table is based on the official `multiformats` convention
// https://github.com/multiformats/multicodec/blob/master/table.csv
/// Table with all the hash functions, code and producing digest lengths.
/// It is the convention behind the [`Multihash format`](https://multiformats.io/multihash/#the-multihash-format).
///
/// Original data from https://github.com/multiformats/multicodec/blob/master/table.csv.
const List<MultiCodec> codecTable = [
  MultiCodec(code: 0x02, name: "cidv2"),
  MultiCodec(code: 0x03, name: "cidv3"),
  MultiCodec(code: 0x18, name: "shake-128"),
  MultiCodec(code: 0x19, name: "shake-256"),
  MultiCodec(code: 0x1a, name: "keccak-224"),
  MultiCodec(code: 0x1b, name: "keccak-256"),
  MultiCodec(code: 0x1c, name: "keccak-384"),
  MultiCodec(code: 0x1d, name: "keccak-512"),
  MultiCodec(code: 0x1e, name: "blake3"),
  MultiCodec(code: 0x21, name: "dccp"),
  MultiCodec(code: 0x23, name: "murmur3-32"),
  MultiCodec(code: 0x2a, name: "ip6zone"),
  MultiCodec(code: 0x2b, name: "ipcidr"),
  MultiCodec(code: 0x30, name: "multicodec"),
  MultiCodec(code: 0x31, name: "multihash"),
  MultiCodec(code: 0x32, name: "multiaddr"),
  MultiCodec(code: 0x33, name: "multibase"),
  MultiCodec(code: 0x34, name: "varsig"),
  MultiCodec(code: 0x50, name: "protobuf"),
  MultiCodec(code: 0x56, name: "dbl-sha2-256"),
  MultiCodec(code: 0x60, name: "rlp"),
  MultiCodec(code: 0x63, name: "bencode"),
  MultiCodec(code: 0x7b, name: "torrent-info"),
  MultiCodec(code: 0x7c, name: "torrent-file"),
  MultiCodec(code: 0x81, name: "leofcoin-block"),
  MultiCodec(code: 0x82, name: "leofcoin-tx"),
  MultiCodec(code: 0x83, name: "leofcoin-pr"),
  MultiCodec(code: 0x84, name: "sctp"),
  MultiCodec(code: 0x85, name: "dag-jose"),
  MultiCodec(code: 0x86, name: "dag-cose"),
  MultiCodec(code: 0x99, name: "eth-receipt-log-trie"),
  MultiCodec(code: 0x9a, name: "eth-receipt-log"),
  MultiCodec(code: 0xa0, name: "aes-128"),
  MultiCodec(code: 0xa1, name: "aes-192"),
  MultiCodec(code: 0xa2, name: "aes-256"),
  MultiCodec(code: 0xa3, name: "chacha-128"),
  MultiCodec(code: 0xa4, name: "chacha-256"),
  MultiCodec(code: 0xca, name: "caip-50"),
  MultiCodec(code: 0xce, name: "streamid"),
  MultiCodec(code: 0xd0, name: "stellar-block"),
  MultiCodec(code: 0xd1, name: "stellar-tx"),
  MultiCodec(code: 0xd4, name: "md4"),
  MultiCodec(code: 0xd5, name: "md5"),
  MultiCodec(code: 0xe0, name: "decred-block"),
  MultiCodec(code: 0xe1, name: "decred-tx"),
  MultiCodec(code: 0xe2, name: "ipld"),
  MultiCodec(code: 0xe3, name: "ipfs"),
  MultiCodec(code: 0xe4, name: "swarm"),
  MultiCodec(code: 0xe5, name: "ipns"),
  MultiCodec(code: 0xe6, name: "zeronet"),
  MultiCodec(code: 0xe7, name: "secp256k1-pub"),
  MultiCodec(code: 0xea, name: "bls12_381-g1-pub"),
  MultiCodec(code: 0xeb, name: "bls12_381-g2-pub"),
  MultiCodec(code: 0xec, name: "x25519-pub"),
  MultiCodec(code: 0xed, name: "ed25519-pub"),
  MultiCodec(code: 0xee, name: "bls12_381-g1g2-pub"),
  MultiCodec(code: 0xef, name: "sr25519-pub"),
  MultiCodec(code: 0xf0, name: "dash-block"),
  MultiCodec(code: 0xf1, name: "dash-tx"),
  MultiCodec(code: 0xfa, name: "swarm-manifest"),
  MultiCodec(code: 0xfb, name: "swarm-feed"),
  MultiCodec(code: 0xfc, name: "beeson"),
  MultiCodec(code: 0x0111, name: "udp"),
  MultiCodec(code: 0x0118, name: "webrtc-direct"),
  MultiCodec(code: 0x0119, name: "webrtc"),
  MultiCodec(code: 0x012d, name: "udt"),
  MultiCodec(code: 0x012e, name: "utp"),
  MultiCodec(code: 0x0132, name: "crc32"),
  MultiCodec(code: 0x0164, name: "crc64-ecma"),
  MultiCodec(code: 0x0196, name: "thread"),
  MultiCodec(code: 0x01bb, name: "https"),
  MultiCodec(code: 0x01bc, name: "onion"),
  MultiCodec(code: 0x01bd, name: "onion3"),
  MultiCodec(code: 0x01be, name: "garlic64"),
  MultiCodec(code: 0x01bf, name: "garlic32"),
  MultiCodec(code: 0x01c0, name: "tls"),
  MultiCodec(code: 0x01c1, name: "sni"),
  MultiCodec(code: 0x01c6, name: "noise"),
  MultiCodec(code: 0x01d1, name: "webtransport"),
  MultiCodec(code: 0x01d2, name: "certhash"),
  MultiCodec(code: 0x01e0, name: "http"),
  MultiCodec(code: 0x01f0, name: "swhid-1-snp"),
  MultiCodec(code: 0x0201, name: "messagepack"),
  MultiCodec(code: 0x0202, name: "car"),
  MultiCodec(code: 0x0400, name: "car-index-sorted"),
  MultiCodec(code: 0x0401, name: "car-multihash-index-sorted"),
  MultiCodec(code: 0x0900, name: "transport-bitswap"),
  MultiCodec(code: 0x0910, name: "transport-graphsync-filecoinv1"),
  MultiCodec(code: 0x0920, name: "transport-ipfs-gateway-http"),
  MultiCodec(code: 0x0d1d, name: "multidid"),
  MultiCodec(code: 0x1022, name: "murmur3-x64-128"),
  MultiCodec(code: 0x1052, name: "ripemd-128"),
  MultiCodec(code: 0x1053, name: "ripemd-160"),
  MultiCodec(code: 0x1054, name: "ripemd-256"),
  MultiCodec(code: 0x1055, name: "ripemd-320"),
  MultiCodec(code: 0x1100, name: "x11"),
  MultiCodec(code: 0x1200, name: "p256-pub"),
  MultiCodec(code: 0x1201, name: "p384-pub"),
  MultiCodec(code: 0x1202, name: "p521-pub"),
  MultiCodec(code: 0x1203, name: "ed448-pub"),
  MultiCodec(code: 0x1204, name: "x448-pub"),
  MultiCodec(code: 0x1205, name: "rsa-pub"),
  MultiCodec(code: 0x1206, name: "sm2-pub"),
  MultiCodec(code: 0x1300, name: "ed25519-priv"),
  MultiCodec(code: 0x1301, name: "secp256k1-priv"),
  MultiCodec(code: 0x1302, name: "x25519-priv"),
  MultiCodec(code: 0x1303, name: "sr25519-priv"),
  MultiCodec(code: 0x1305, name: "rsa-priv"),
  MultiCodec(code: 0x1306, name: "p256-priv"),
  MultiCodec(code: 0x1307, name: "p384-priv"),
  MultiCodec(code: 0x1308, name: "p521-priv"),
  MultiCodec(code: 0x1d01, name: "kangarootwelve"),
  MultiCodec(code: 0x2000, name: "aes-gcm-256"),
  MultiCodec(code: 0x3f42, name: "silverpine"),
  MultiCodec(code: 0x534d, name: "sm3-256"),
  MultiCodec(code: 0xb201, name: "blake2b-8"),
  MultiCodec(code: 0xb202, name: "blake2b-16"),
  MultiCodec(code: 0xb203, name: "blake2b-24"),
  MultiCodec(code: 0xb204, name: "blake2b-32"),
  MultiCodec(code: 0xb205, name: "blake2b-40"),
  MultiCodec(code: 0xb206, name: "blake2b-48"),
  MultiCodec(code: 0xb207, name: "blake2b-56"),
  MultiCodec(code: 0xb208, name: "blake2b-64"),
  MultiCodec(code: 0xb209, name: "blake2b-72"),
  MultiCodec(code: 0xb20a, name: "blake2b-80"),
  MultiCodec(code: 0xb20b, name: "blake2b-88"),
  MultiCodec(code: 0xb20c, name: "blake2b-96"),
  MultiCodec(code: 0xb20d, name: "blake2b-104"),
  MultiCodec(code: 0xb20e, name: "blake2b-112"),
  MultiCodec(code: 0xb20f, name: "blake2b-120"),
  MultiCodec(code: 0xb210, name: "blake2b-128"),
  MultiCodec(code: 0xb211, name: "blake2b-136"),
  MultiCodec(code: 0xb212, name: "blake2b-144"),
  MultiCodec(code: 0xb213, name: "blake2b-152"),
  MultiCodec(code: 0xb214, name: "blake2b-160"),
  MultiCodec(code: 0xb215, name: "blake2b-168"),
  MultiCodec(code: 0xb216, name: "blake2b-176"),
  MultiCodec(code: 0xb217, name: "blake2b-184"),
  MultiCodec(code: 0xb218, name: "blake2b-192"),
  MultiCodec(code: 0xb219, name: "blake2b-200"),
  MultiCodec(code: 0xb21a, name: "blake2b-208"),
  MultiCodec(code: 0xb21b, name: "blake2b-216"),
  MultiCodec(code: 0xb21c, name: "blake2b-224"),
  MultiCodec(code: 0xb21d, name: "blake2b-232"),
  MultiCodec(code: 0xb21e, name: "blake2b-240"),
  MultiCodec(code: 0xb21f, name: "blake2b-248"),
  MultiCodec(code: 0xb221, name: "blake2b-264"),
  MultiCodec(code: 0xb222, name: "blake2b-272"),
  MultiCodec(code: 0xb223, name: "blake2b-280"),
  MultiCodec(code: 0xb224, name: "blake2b-288"),
  MultiCodec(code: 0xb225, name: "blake2b-296"),
  MultiCodec(code: 0xb226, name: "blake2b-304"),
  MultiCodec(code: 0xb227, name: "blake2b-312"),
  MultiCodec(code: 0xb228, name: "blake2b-320"),
  MultiCodec(code: 0xb229, name: "blake2b-328"),
  MultiCodec(code: 0xb22a, name: "blake2b-336"),
  MultiCodec(code: 0xb22b, name: "blake2b-344"),
  MultiCodec(code: 0xb22c, name: "blake2b-352"),
  MultiCodec(code: 0xb22d, name: "blake2b-360"),
  MultiCodec(code: 0xb22e, name: "blake2b-368"),
  MultiCodec(code: 0xb22f, name: "blake2b-376"),
  MultiCodec(code: 0xb230, name: "blake2b-384"),
  MultiCodec(code: 0xb231, name: "blake2b-392"),
  MultiCodec(code: 0xb232, name: "blake2b-400"),
  MultiCodec(code: 0xb233, name: "blake2b-408"),
  MultiCodec(code: 0xb234, name: "blake2b-416"),
  MultiCodec(code: 0xb235, name: "blake2b-424"),
  MultiCodec(code: 0xb236, name: "blake2b-432"),
  MultiCodec(code: 0xb237, name: "blake2b-440"),
  MultiCodec(code: 0xb238, name: "blake2b-448"),
  MultiCodec(code: 0xb239, name: "blake2b-456"),
  MultiCodec(code: 0xb23a, name: "blake2b-464"),
  MultiCodec(code: 0xb23b, name: "blake2b-472"),
  MultiCodec(code: 0xb23c, name: "blake2b-480"),
  MultiCodec(code: 0xb23d, name: "blake2b-488"),
  MultiCodec(code: 0xb23e, name: "blake2b-496"),
  MultiCodec(code: 0xb23f, name: "blake2b-504"),
  MultiCodec(code: 0xb240, name: "blake2b-512"),
  MultiCodec(code: 0xb241, name: "blake2s-8"),
  MultiCodec(code: 0xb242, name: "blake2s-16"),
  MultiCodec(code: 0xb243, name: "blake2s-24"),
  MultiCodec(code: 0xb244, name: "blake2s-32"),
  MultiCodec(code: 0xb245, name: "blake2s-40"),
  MultiCodec(code: 0xb246, name: "blake2s-48"),
  MultiCodec(code: 0xb247, name: "blake2s-56"),
  MultiCodec(code: 0xb248, name: "blake2s-64"),
  MultiCodec(code: 0xb249, name: "blake2s-72"),
  MultiCodec(code: 0xb24a, name: "blake2s-80"),
  MultiCodec(code: 0xb24b, name: "blake2s-88"),
  MultiCodec(code: 0xb24c, name: "blake2s-96"),
  MultiCodec(code: 0xb24d, name: "blake2s-104"),
  MultiCodec(code: 0xb24e, name: "blake2s-112"),
  MultiCodec(code: 0xb24f, name: "blake2s-120"),
  MultiCodec(code: 0xb250, name: "blake2s-128"),
  MultiCodec(code: 0xb251, name: "blake2s-136"),
  MultiCodec(code: 0xb252, name: "blake2s-144"),
  MultiCodec(code: 0xb253, name: "blake2s-152"),
  MultiCodec(code: 0xb254, name: "blake2s-160"),
  MultiCodec(code: 0xb255, name: "blake2s-168"),
  MultiCodec(code: 0xb256, name: "blake2s-176"),
  MultiCodec(code: 0xb257, name: "blake2s-184"),
  MultiCodec(code: 0xb258, name: "blake2s-192"),
  MultiCodec(code: 0xb259, name: "blake2s-200"),
  MultiCodec(code: 0xb25a, name: "blake2s-208"),
  MultiCodec(code: 0xb25b, name: "blake2s-216"),
  MultiCodec(code: 0xb25c, name: "blake2s-224"),
  MultiCodec(code: 0xb25d, name: "blake2s-232"),
  MultiCodec(code: 0xb25e, name: "blake2s-240"),
  MultiCodec(code: 0xb25f, name: "blake2s-248"),
  MultiCodec(code: 0xb260, name: "blake2s-256"),
  MultiCodec(code: 0xb301, name: "skein256-8"),
  MultiCodec(code: 0xb302, name: "skein256-16"),
  MultiCodec(code: 0xb303, name: "skein256-24"),
  MultiCodec(code: 0xb304, name: "skein256-32"),
  MultiCodec(code: 0xb305, name: "skein256-40"),
  MultiCodec(code: 0xb306, name: "skein256-48"),
  MultiCodec(code: 0xb307, name: "skein256-56"),
  MultiCodec(code: 0xb308, name: "skein256-64"),
  MultiCodec(code: 0xb309, name: "skein256-72"),
  MultiCodec(code: 0xb30a, name: "skein256-80"),
  MultiCodec(code: 0xb30b, name: "skein256-88"),
  MultiCodec(code: 0xb30c, name: "skein256-96"),
  MultiCodec(code: 0xb30d, name: "skein256-104"),
  MultiCodec(code: 0xb30e, name: "skein256-112"),
  MultiCodec(code: 0xb30f, name: "skein256-120"),
  MultiCodec(code: 0xb310, name: "skein256-128"),
  MultiCodec(code: 0xb311, name: "skein256-136"),
  MultiCodec(code: 0xb312, name: "skein256-144"),
  MultiCodec(code: 0xb313, name: "skein256-152"),
  MultiCodec(code: 0xb314, name: "skein256-160"),
  MultiCodec(code: 0xb315, name: "skein256-168"),
  MultiCodec(code: 0xb316, name: "skein256-176"),
  MultiCodec(code: 0xb317, name: "skein256-184"),
  MultiCodec(code: 0xb318, name: "skein256-192"),
  MultiCodec(code: 0xb319, name: "skein256-200"),
  MultiCodec(code: 0xb31a, name: "skein256-208"),
  MultiCodec(code: 0xb31b, name: "skein256-216"),
  MultiCodec(code: 0xb31c, name: "skein256-224"),
  MultiCodec(code: 0xb31d, name: "skein256-232"),
  MultiCodec(code: 0xb31e, name: "skein256-240"),
  MultiCodec(code: 0xb31f, name: "skein256-248"),
  MultiCodec(code: 0xb320, name: "skein256-256"),
  MultiCodec(code: 0xb321, name: "skein512-8"),
  MultiCodec(code: 0xb322, name: "skein512-16"),
  MultiCodec(code: 0xb323, name: "skein512-24"),
  MultiCodec(code: 0xb324, name: "skein512-32"),
  MultiCodec(code: 0xb325, name: "skein512-40"),
  MultiCodec(code: 0xb326, name: "skein512-48"),
  MultiCodec(code: 0xb327, name: "skein512-56"),
  MultiCodec(code: 0xb328, name: "skein512-64"),
  MultiCodec(code: 0xb329, name: "skein512-72"),
  MultiCodec(code: 0xb32a, name: "skein512-80"),
  MultiCodec(code: 0xb32b, name: "skein512-88"),
  MultiCodec(code: 0xb32c, name: "skein512-96"),
  MultiCodec(code: 0xb32d, name: "skein512-104"),
  MultiCodec(code: 0xb32e, name: "skein512-112"),
  MultiCodec(code: 0xb32f, name: "skein512-120"),
  MultiCodec(code: 0xb330, name: "skein512-128"),
  MultiCodec(code: 0xb331, name: "skein512-136"),
  MultiCodec(code: 0xb332, name: "skein512-144"),
  MultiCodec(code: 0xb333, name: "skein512-152"),
  MultiCodec(code: 0xb334, name: "skein512-160"),
  MultiCodec(code: 0xb335, name: "skein512-168"),
  MultiCodec(code: 0xb336, name: "skein512-176"),
  MultiCodec(code: 0xb337, name: "skein512-184"),
  MultiCodec(code: 0xb338, name: "skein512-192"),
  MultiCodec(code: 0xb339, name: "skein512-200"),
  MultiCodec(code: 0xb33a, name: "skein512-208"),
  MultiCodec(code: 0xb33b, name: "skein512-216"),
  MultiCodec(code: 0xb33c, name: "skein512-224"),
  MultiCodec(code: 0xb33d, name: "skein512-232"),
  MultiCodec(code: 0xb33e, name: "skein512-240"),
  MultiCodec(code: 0xb33f, name: "skein512-248"),
  MultiCodec(code: 0xb340, name: "skein512-256"),
  MultiCodec(code: 0xb341, name: "skein512-264"),
  MultiCodec(code: 0xb342, name: "skein512-272"),
  MultiCodec(code: 0xb343, name: "skein512-280"),
  MultiCodec(code: 0xb344, name: "skein512-288"),
  MultiCodec(code: 0xb345, name: "skein512-296"),
  MultiCodec(code: 0xb346, name: "skein512-304"),
  MultiCodec(code: 0xb347, name: "skein512-312"),
  MultiCodec(code: 0xb348, name: "skein512-320"),
  MultiCodec(code: 0xb349, name: "skein512-328"),
  MultiCodec(code: 0xb34a, name: "skein512-336"),
  MultiCodec(code: 0xb34b, name: "skein512-344"),
  MultiCodec(code: 0xb34c, name: "skein512-352"),
  MultiCodec(code: 0xb34d, name: "skein512-360"),
  MultiCodec(code: 0xb34e, name: "skein512-368"),
  MultiCodec(code: 0xb34f, name: "skein512-376"),
  MultiCodec(code: 0xb350, name: "skein512-384"),
  MultiCodec(code: 0xb351, name: "skein512-392"),
  MultiCodec(code: 0xb352, name: "skein512-400"),
  MultiCodec(code: 0xb353, name: "skein512-408"),
  MultiCodec(code: 0xb354, name: "skein512-416"),
  MultiCodec(code: 0xb355, name: "skein512-424"),
  MultiCodec(code: 0xb356, name: "skein512-432"),
  MultiCodec(code: 0xb357, name: "skein512-440"),
  MultiCodec(code: 0xb358, name: "skein512-448"),
  MultiCodec(code: 0xb359, name: "skein512-456"),
  MultiCodec(code: 0xb35a, name: "skein512-464"),
  MultiCodec(code: 0xb35b, name: "skein512-472"),
  MultiCodec(code: 0xb35c, name: "skein512-480"),
  MultiCodec(code: 0xb35d, name: "skein512-488"),
  MultiCodec(code: 0xb35e, name: "skein512-496"),
  MultiCodec(code: 0xb35f, name: "skein512-504"),
  MultiCodec(code: 0xb360, name: "skein512-512"),
  MultiCodec(code: 0xb361, name: "skein1024-8"),
  MultiCodec(code: 0xb362, name: "skein1024-16"),
  MultiCodec(code: 0xb363, name: "skein1024-24"),
  MultiCodec(code: 0xb364, name: "skein1024-32"),
  MultiCodec(code: 0xb365, name: "skein1024-40"),
  MultiCodec(code: 0xb366, name: "skein1024-48"),
  MultiCodec(code: 0xb367, name: "skein1024-56"),
  MultiCodec(code: 0xb368, name: "skein1024-64"),
  MultiCodec(code: 0xb369, name: "skein1024-72"),
  MultiCodec(code: 0xb36a, name: "skein1024-80"),
  MultiCodec(code: 0xb36b, name: "skein1024-88"),
  MultiCodec(code: 0xb36c, name: "skein1024-96"),
  MultiCodec(code: 0xb36d, name: "skein1024-104"),
  MultiCodec(code: 0xb36e, name: "skein1024-112"),
  MultiCodec(code: 0xb36f, name: "skein1024-120"),
  MultiCodec(code: 0xb370, name: "skein1024-128"),
  MultiCodec(code: 0xb371, name: "skein1024-136"),
  MultiCodec(code: 0xb372, name: "skein1024-144"),
  MultiCodec(code: 0xb373, name: "skein1024-152"),
  MultiCodec(code: 0xb374, name: "skein1024-160"),
  MultiCodec(code: 0xb375, name: "skein1024-168"),
  MultiCodec(code: 0xb376, name: "skein1024-176"),
  MultiCodec(code: 0xb377, name: "skein1024-184"),
  MultiCodec(code: 0xb378, name: "skein1024-192"),
  MultiCodec(code: 0xb379, name: "skein1024-200"),
  MultiCodec(code: 0xb37a, name: "skein1024-208"),
  MultiCodec(code: 0xb37b, name: "skein1024-216"),
  MultiCodec(code: 0xb37c, name: "skein1024-224"),
  MultiCodec(code: 0xb37d, name: "skein1024-232"),
  MultiCodec(code: 0xb37e, name: "skein1024-240"),
  MultiCodec(code: 0xb37f, name: "skein1024-248"),
  MultiCodec(code: 0xb380, name: "skein1024-256"),
  MultiCodec(code: 0xb381, name: "skein1024-264"),
  MultiCodec(code: 0xb382, name: "skein1024-272"),
  MultiCodec(code: 0xb383, name: "skein1024-280"),
  MultiCodec(code: 0xb384, name: "skein1024-288"),
  MultiCodec(code: 0xb385, name: "skein1024-296"),
  MultiCodec(code: 0xb386, name: "skein1024-304"),
  MultiCodec(code: 0xb387, name: "skein1024-312"),
  MultiCodec(code: 0xb388, name: "skein1024-320"),
  MultiCodec(code: 0xb389, name: "skein1024-328"),
  MultiCodec(code: 0xb38a, name: "skein1024-336"),
  MultiCodec(code: 0xb38b, name: "skein1024-344"),
  MultiCodec(code: 0xb38c, name: "skein1024-352"),
  MultiCodec(code: 0xb38d, name: "skein1024-360"),
  MultiCodec(code: 0xb38e, name: "skein1024-368"),
  MultiCodec(code: 0xb38f, name: "skein1024-376"),
  MultiCodec(code: 0xb390, name: "skein1024-384"),
  MultiCodec(code: 0xb391, name: "skein1024-392"),
  MultiCodec(code: 0xb392, name: "skein1024-400"),
  MultiCodec(code: 0xb393, name: "skein1024-408"),
  MultiCodec(code: 0xb394, name: "skein1024-416"),
  MultiCodec(code: 0xb395, name: "skein1024-424"),
  MultiCodec(code: 0xb396, name: "skein1024-432"),
  MultiCodec(code: 0xb397, name: "skein1024-440"),
  MultiCodec(code: 0xb398, name: "skein1024-448"),
  MultiCodec(code: 0xb399, name: "skein1024-456"),
  MultiCodec(code: 0xb39a, name: "skein1024-464"),
  MultiCodec(code: 0xb39b, name: "skein1024-472"),
  MultiCodec(code: 0xb39c, name: "skein1024-480"),
  MultiCodec(code: 0xb39d, name: "skein1024-488"),
  MultiCodec(code: 0xb39e, name: "skein1024-496"),
  MultiCodec(code: 0xb39f, name: "skein1024-504"),
  MultiCodec(code: 0xb3a0, name: "skein1024-512"),
  MultiCodec(code: 0xb3a1, name: "skein1024-520"),
  MultiCodec(code: 0xb3a2, name: "skein1024-528"),
  MultiCodec(code: 0xb3a3, name: "skein1024-536"),
  MultiCodec(code: 0xb3a4, name: "skein1024-544"),
  MultiCodec(code: 0xb3a5, name: "skein1024-552"),
  MultiCodec(code: 0xb3a6, name: "skein1024-560"),
  MultiCodec(code: 0xb3a7, name: "skein1024-568"),
  MultiCodec(code: 0xb3a8, name: "skein1024-576"),
  MultiCodec(code: 0xb3a9, name: "skein1024-584"),
  MultiCodec(code: 0xb3aa, name: "skein1024-592"),
  MultiCodec(code: 0xb3ab, name: "skein1024-600"),
  MultiCodec(code: 0xb3ac, name: "skein1024-608"),
  MultiCodec(code: 0xb3ad, name: "skein1024-616"),
  MultiCodec(code: 0xb3ae, name: "skein1024-624"),
  MultiCodec(code: 0xb3af, name: "skein1024-632"),
  MultiCodec(code: 0xb3b0, name: "skein1024-640"),
  MultiCodec(code: 0xb3b1, name: "skein1024-648"),
  MultiCodec(code: 0xb3b2, name: "skein1024-656"),
  MultiCodec(code: 0xb3b3, name: "skein1024-664"),
  MultiCodec(code: 0xb3b4, name: "skein1024-672"),
  MultiCodec(code: 0xb3b5, name: "skein1024-680"),
  MultiCodec(code: 0xb3b6, name: "skein1024-688"),
  MultiCodec(code: 0xb3b7, name: "skein1024-696"),
  MultiCodec(code: 0xb3b8, name: "skein1024-704"),
  MultiCodec(code: 0xb3b9, name: "skein1024-712"),
  MultiCodec(code: 0xb3ba, name: "skein1024-720"),
  MultiCodec(code: 0xb3bb, name: "skein1024-728"),
  MultiCodec(code: 0xb3bc, name: "skein1024-736"),
  MultiCodec(code: 0xb3bd, name: "skein1024-744"),
  MultiCodec(code: 0xb3be, name: "skein1024-752"),
  MultiCodec(code: 0xb3bf, name: "skein1024-760"),
  MultiCodec(code: 0xb3c0, name: "skein1024-768"),
  MultiCodec(code: 0xb3c1, name: "skein1024-776"),
  MultiCodec(code: 0xb3c2, name: "skein1024-784"),
  MultiCodec(code: 0xb3c3, name: "skein1024-792"),
  MultiCodec(code: 0xb3c4, name: "skein1024-800"),
  MultiCodec(code: 0xb3c5, name: "skein1024-808"),
  MultiCodec(code: 0xb3c6, name: "skein1024-816"),
  MultiCodec(code: 0xb3c7, name: "skein1024-824"),
  MultiCodec(code: 0xb3c8, name: "skein1024-832"),
  MultiCodec(code: 0xb3c9, name: "skein1024-840"),
  MultiCodec(code: 0xb3ca, name: "skein1024-848"),
  MultiCodec(code: 0xb3cb, name: "skein1024-856"),
  MultiCodec(code: 0xb3cc, name: "skein1024-864"),
  MultiCodec(code: 0xb3cd, name: "skein1024-872"),
  MultiCodec(code: 0xb3ce, name: "skein1024-880"),
  MultiCodec(code: 0xb3cf, name: "skein1024-888"),
  MultiCodec(code: 0xb3d0, name: "skein1024-896"),
  MultiCodec(code: 0xb3d1, name: "skein1024-904"),
  MultiCodec(code: 0xb3d2, name: "skein1024-912"),
  MultiCodec(code: 0xb3d3, name: "skein1024-920"),
  MultiCodec(code: 0xb3d4, name: "skein1024-928"),
  MultiCodec(code: 0xb3d5, name: "skein1024-936"),
  MultiCodec(code: 0xb3d6, name: "skein1024-944"),
  MultiCodec(code: 0xb3d7, name: "skein1024-952"),
  MultiCodec(code: 0xb3d8, name: "skein1024-960"),
  MultiCodec(code: 0xb3d9, name: "skein1024-968"),
  MultiCodec(code: 0xb3da, name: "skein1024-976"),
  MultiCodec(code: 0xb3db, name: "skein1024-984"),
  MultiCodec(code: 0xb3dc, name: "skein1024-992"),
  MultiCodec(code: 0xb3dd, name: "skein1024-1000"),
  MultiCodec(code: 0xb3de, name: "skein1024-1008"),
  MultiCodec(code: 0xb3df, name: "skein1024-1016"),
  MultiCodec(code: 0xb3e0, name: "skein1024-1024"),
  MultiCodec(code: 0xb3e1, name: "xxh-32"),
  MultiCodec(code: 0xb3e2, name: "xxh-64"),
  MultiCodec(code: 0xb3e3, name: "xxh3-64"),
  MultiCodec(code: 0xb3e4, name: "xxh3-128"),
  MultiCodec(code: 0xb402, name: "poseidon-bls12_381-a2-fc1-sc"),
  MultiCodec(code: 0xb403, name: "urdca-2015-canon"),
  MultiCodec(code: 0xb501, name: "ssz"),
  MultiCodec(code: 0xb502, name: "ssz-sha2-256-bmt"),
  MultiCodec(code: 0xb601, name: "json-jcs"),
  MultiCodec(code: 0xcc01, name: "iscc"),
  MultiCodec(code: 0xce11, name: "zeroxcert-imprint-256"),
  MultiCodec(code: 0xd0e7, name: "es256k"),
  MultiCodec(code: 0xd0ea, name: "bls-12381-g1-sig"),
  MultiCodec(code: 0xd0eb, name: "bls-12381-g2-sig"),
  MultiCodec(code: 0xd0ed, name: "eddsa"),
  MultiCodec(code: 0xd191, name: "eip-191"),
  MultiCodec(code: 0xeb51, name: "jwk_jcs-pub"),
  MultiCodec(code: 0x706c61, name: "plaintextv2"),
  MultiCodec(code: 0x807124, name: "holochain-adr-v0"),
  MultiCodec(code: 0x817124, name: "holochain-adr-v1"),
  MultiCodec(code: 0x947124, name: "holochain-key-v0"),
  MultiCodec(code: 0x957124, name: "holochain-key-v1"),
  MultiCodec(code: 0xa27124, name: "holochain-sig-v0"),
  MultiCodec(code: 0xa37124, name: "holochain-sig-v1"),
  MultiCodec(code: 0xb19910, name: "skynet-ns"),
  MultiCodec(code: 0xb29910, name: "arweave-ns"),
  MultiCodec(code: 0xb39910, name: "subspace-ns"),
  MultiCodec(code: 0xb49910, name: "kumandra-ns"),
  MultiCodec(code: 0xd01200, name: "es256"),
  MultiCodec(code: 0xd01201, name: "es284"),
  MultiCodec(code: 0xd01202, name: "es512"),
  MultiCodec(code: 0xd01205, name: "rs256"),
  MultiCodec(code: 0xd02000, name: "scion"),
  MultiCodec(code: 0x00, name: "identity"),
  MultiCodec(code: 0x01, name: "cidv1"),
  MultiCodec(code: 0x04, name: "ip4"),
  MultiCodec(code: 0x06, name: "tcp"),
  MultiCodec(code: 0x11, name: "sha1"),
  MultiCodec(code: 0x12, name: "sha2-256"),
  MultiCodec(code: 0x13, name: "sha2-512"),
  MultiCodec(code: 0x14, name: "sha3-512"),
  MultiCodec(code: 0x15, name: "sha3-384"),
  MultiCodec(code: 0x16, name: "sha3-256"),
  MultiCodec(code: 0x17, name: "sha3-224"),
  MultiCodec(code: 0x20, name: "sha2-384"),
  MultiCodec(code: 0x22, name: "murmur3-x64-64"),
  MultiCodec(code: 0x29, name: "ip6"),
  MultiCodec(code: 0x2f, name: "path"),
  MultiCodec(code: 0x35, name: "dns"),
  MultiCodec(code: 0x36, name: "dns4"),
  MultiCodec(code: 0x37, name: "dns6"),
  MultiCodec(code: 0x38, name: "dnsaddr"),
  MultiCodec(code: 0x51, name: "cbor"),
  MultiCodec(code: 0x55, name: "raw"),
  MultiCodec(code: 0x70, name: "dag-pb"),
  MultiCodec(code: 0x71, name: "dag-cbor"),
  MultiCodec(code: 0x72, name: "libp2p-key"),
  MultiCodec(code: 0x78, name: "git-raw"),
  MultiCodec(code: 0x90, name: "eth-block"),
  MultiCodec(code: 0x91, name: "eth-block-list"),
  MultiCodec(code: 0x92, name: "eth-tx-trie"),
  MultiCodec(code: 0x93, name: "eth-tx"),
  MultiCodec(code: 0x94, name: "eth-tx-receipt-trie"),
  MultiCodec(code: 0x95, name: "eth-tx-receipt"),
  MultiCodec(code: 0x96, name: "eth-state-trie"),
  MultiCodec(code: 0x97, name: "eth-account-snapshot"),
  MultiCodec(code: 0x98, name: "eth-storage-trie"),
  MultiCodec(code: 0xb0, name: "bitcoin-block"),
  MultiCodec(code: 0xb1, name: "bitcoin-tx"),
  MultiCodec(code: 0xb2, name: "bitcoin-witness-commitment"),
  MultiCodec(code: 0xc0, name: "zcash-block"),
  MultiCodec(code: 0xc1, name: "zcash-tx"),
  MultiCodec(code: 0xe8, name: "dnslink"),
  MultiCodec(code: 0x0122, name: "p2p-circuit"),
  MultiCodec(code: 0x0129, name: "dag-json"),
  MultiCodec(code: 0x0190, name: "unix"),
  MultiCodec(code: 0x01a5, name: "p2p"),
  MultiCodec(code: 0x01cc, name: "quic"),
  MultiCodec(code: 0x01cd, name: "quic-v1"),
  MultiCodec(code: 0x01dd, name: "ws"),
  MultiCodec(code: 0x01de, name: "wss"),
  MultiCodec(code: 0x01df, name: "p2p-websocket-star"),
  MultiCodec(code: 0x0200, name: "json"),
  MultiCodec(code: 0x0300, name: "ipns-record"),
  MultiCodec(code: 0x0301, name: "libp2p-peer-record"),
  MultiCodec(code: 0x0302, name: "libp2p-relay-rsvp"),
  MultiCodec(code: 0x0309, name: "memorytransport"),
  MultiCodec(code: 0x1012, name: "sha2-256-trunc254-padded"),
  MultiCodec(code: 0x1013, name: "sha2-224"),
  MultiCodec(code: 0x1014, name: "sha2-512-224"),
  MultiCodec(code: 0x1015, name: "sha2-512-256"),
  MultiCodec(code: 0xb220, name: "blake2b-256"),
  MultiCodec(code: 0xb401, name: "poseidon-bls12_381-a2-fc1"),
  MultiCodec(code: 0xf101, name: "fil-commitment-unsealed"),
  MultiCodec(code: 0xf102, name: "fil-commitment-sealed")
];

/// Array of supported hash function names.
final supportedHashFunctions = codecTable.map((e) => e.name);

/// Array of supported hash codes found in the [`Multihash format`](https://multiformats.io/multihash/#the-multihash-format).
final supportedHashCodes = codecTable.map((e) => e.code);
